.. dustmaps documentation master file, created by
   sphinx-quickstart on Fri Oct 14 17:20:58 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

dustmaps documentation
====================================

:code:`dustmaps` provides a unified interface for several 2D and 3D
maps of interstellar dust reddening and extinction.

To get started, take a look at :doc:`installation` and
:doc:`examples`. To see a list of all available maps, take a look
at :doc:`maps`. For a complete reference to the API, see
:doc:`modules`.

If you make use of :code:`dustmaps` in your research, please cite
`Green (2018) <https://doi.org/10.21105/joss.00695>`_::

    @ARTICLE{2018JOSS....3..695M,
           author = {{Green}, {Gregory M.}},
            title = "{dustmaps: A Python interface for maps of interstellar dust}",
          journal = {The Journal of Open Source Software},
             year = "2018",
            month = "Jun",
           volume = {3},
           number = {26},
            pages = {695},
              doi = {10.21105/joss.00695},
           adsurl = {https://ui.adsabs.harvard.edu/abs/2018JOSS....3..695G},
          adsnote = {Provided by the SAO/NASA Astrophysics Data System}
    }


Contents
========

.. toctree::
   :maxdepth: 2
   
   installation
   examples
   maps
   modules
   license


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
